@@ -1,5 +1,6 @@
 mod assets;
 use rand::seq::SliceRandom;
+use regex::Regex;
 
 pub fn generate() -> [char; 5] {
     let mut ans = ['a'; 5];
@@ -17,3 +18,8 @@ pub fn generate() -> [char; 5] {
 pub fn is_valid_word(word: &str) -> bool {
     assets::CANDIDATES.contains(&word) || assets::VALID_WORDS.contains(&word)
 }
+
+pub fn is_five_letter_word(word: &str) -> bool {
+    let five_letter_word = Regex::new(r"^[a-zA-Z]{5}$").unwrap();
+    five_letter_word.is_match(word)
+}
